powered by
Extends edge values of a raster or matrix by a specified number of pixels.
pad_edges(x, size, val = NULL)
A raster with edges padded size number of pixels on each edge.
size
A matrix.
Numeric. Number of pixels to add to each side.
Numeric. If NULL (default), this extends the edge values out. If not null, this value will be used for the extended cells.
library(raster) # import raster image data(normforest) # crop raster to much smaller area x <- pad_edges(as.matrix(normforest), 3, val = NA)
Run the code above in your browser using DataLab