Learn R Programming

geodiv (version 1.0.5)

sds: Summit Density

Description

Calculates the summit density of a raster or matrix. Summit density is the number of local peaks per unit area.

Usage

sds(x)

Value

A numeric value representing the summit density.

Arguments

x

A raster or matrix.

Examples

Run this code
# import raster image
data(normforest)

# calculate summit density.
Sds <- sds(normforest)

Run the code above in your browser using DataLab