Learn R Programming

geodiv (version 1.0.5)

sfd_: Calculate the fractal dimension of a raster (C function).

Description

Calculates the 3D fractal dimension of a raster using the triangular prism surface area method.

Usage

sfd_(mat)

Value

A numeric value representing the fractal dimension of the image.

Arguments

mat

A matrix.

References

Clarke, K.C., 1986. Computation of the fractal dimension of topographic surfaces using the triangular prism surface area method. Computers & Geosciences, 12(5), pp.713-722.

Examples

Run this code

# import raster image
data(normforest)

# convert to matrix
mat <- raster::as.matrix(normforest)

# calculate the fractal dimension
Sfd <- sfd_(mat)

Run the code above in your browser using DataLab