Learn R Programming

geodiv (version 1.0.5)

spk: Reduced Peak Height

Description

Determines the reduced peak height (Spk), the height difference between the maximum y value of the bearing area curve and the y value of the highest intersection point of the least mean square line fit to the flattest 40% of the bearing area curve. See Figure 2a from Kedron et al. (2018) for more details.

Usage

spk(x)

Value

A numeric value representing the reduced peak height.

Arguments

x

A raster or matrix.

Examples

Run this code
# import raster image
data(normforest)

# determine the reduced peak height
Spk <- spk(normforest)

Run the code above in your browser using DataLab