Calculates the dominant radial wavelength, radial wavelength
index, and mean half wavelength of the radial Fourier spectrum.
See Kedron et al. (2018) for more detailed description.
Usage
srw(x, create_plot = FALSE, option = c(1, 2, 3))
Value
A vector containing numeric values for the dominant
radial wavelength, radial wavelength index, and mean half
wavelength.
Arguments
x
A raster or matrix.
create_plot
Logical. If TRUE, returns a plot of the
amplitude spectrum with lines showing the radii at which
Srw, Srwi, and Shw are calculated.
option
Numeric. Code for which output metric(s) to return. 1 = Srw, 2 = Srwi, 3 = Shw.